##  Getting Started with Self-Built Software Discovery
Before you start, provision your workspace for self-built software discovery in the admin area. For details, see [Workspace Setup for Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Provision the self-built software discovery feature in SAP LeanIX to enable microservice discovery. This extends the meta model with microservice fact sheets, custom relations, and additional context fields.").
To get started with self-built software discovery, follow these key steps:
  1. Discover microservices: Set up automated microservice discovery using a manifest file stored in your Git repository. To learn more, see [Microservice Discovery in Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline?locale=en-US&state=PRODUCTION&version=CLOUD "Set up microservice discovery using a manifest file in your repository. This method, known as configuration-as-code, enables you to automatically discover microservices and update corresponding fact sheets in SAP LeanIX.").
  2. Ingest SBOMs: Use the [Self-Built Software Discovery API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Feu.leanix.net%2Fservices%2Ftechnology-discovery%2Fv1%2Fopenapi%2Fswagger-ui%2Findex.html%23%2Fmicroservices%2Fleanix-v1-microservices-sboms-ingest "https://eu.leanix.net/services/technology-discovery/v1/openapi/swagger-ui/index.html#/microservices/leanix-v1-microservices-sboms-ingest") to attach SBOMs (CycloneDX and SPDX) to your previously discovered microservices. If you don't have an existing SBOM process yet, refer to our documentation on [generating SBOMs](https://help.sap.com/docs/leanix/ea/generating-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Explore the requirements for SBOM files and get an overview of the methods for generating them."). To learn more about SBOM, see [Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom?locale=en-US&state=PRODUCTION&version=CLOUD "To understand and manage dependencies among your microservices, generate SBOM files and ingest them into SAP LeanIX using our API.").
  3. Explore discovered tech stack: SBOM components are matched against a curated reference catalog, and IT components are automatically created and linked to relevant microservices. To learn more, see [Tech Stack Discovery from SBOMs](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically discover tech stacks from ingested SBOMs. Add custom tech stacks manually to complete your technology portfolio.").
